==> nextcloud-app-mail-5.1.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/id.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Penting",
    "Work" : "Kantor",
    "Personal" : "Pribadi",
    "Later" : "Nanti",
    "Mail" : "Surel",
    "Connecting" : "Menyambungkan",
    "Save" : "Simpan",
    "Connect" : "Sambungkan",
    "Password required" : "Kata sandi diperlukan",
    "Name" : "Nama",
    "Password" : "Kata kunci",
    "None" : "Tidak ada",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "Kata sandi SMTP",
    "Signature" : "Tanda",
    "Filters" : "Penyaring",
    "Go back" : "Kembali",
    "Email address" : "Alamat surel",
    "Cancel" : "Membatalkan",
    "Accounts" : "Accounts",
    "Add mail account" : "Tambahkan akun surel",
    "General" : "Umum",
    "List" : "Daftar",
    "Register" : "Daftar",
    "About" : "Tentang",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "Archive" : "Arsip",
    "Delete" : "Hapus",
    "Search" : "Cari",
    "Send" : "Kirim",
    "Refresh" : "Segarkan",
    "Subject" : "Subjek",
    "Upload attachment" : "Unggah lampiran",
    "Choose" : "Pilih",
    "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
    "Confirm" : "Konfirmasi",
    "Favorite" : "Favorit",
    "Read" : "Baca",
    "Edit tags" : "Sunting label",
    "Back" : "Kembali",
    "Create event" : "Buat acara",
    "All day" : "Sepanjang hari",
    "Description" : "Deskrisi",
    "Create" : "Buat",
    "Select" : "Pilih",
    "Comment" : "Komentar",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "Remove" : "Buang",
    "email" : "surel",
    "Other" : "Lainnya",
    "Forward" : "Teruskan",
    "Translate" : "Terjemahkan",
    "Choose a folder to store the attachment in" : "Pilih folder untuk menyimpan lampiran didalamnya",
    "Import into calendar" : "Impor ke kalender",
    "Download attachment" : "Unduh lampiran",
    "Move" : "Pindah",
    "Loading …" : "Memuat …",
    "Remove account" : "Hapus akun",
    "Quota" : "Kuota",
    "Saving" : "Menyimpan",
    "Mark all as read" : "Tandai semua telah dibaca",
    "Rename" : "Ubah nama",
    "Clear cache" : "Bersihkan cache",
    "New message" : "Pesan baru",
    "Draft" : "Draf",
    "Reply" : "Balas",
    "Retry" : "Ulangi",
    "Message" : "Pesan",
    "Copy to clipboard" : "Salin ke papan klip",
    "Add" : "Masukkan",
    "Show less" : "Lihat sedikit",
    "Clear" : "Bersihkan",
    "Close" : "Tutup",
    "Date" : "Date",
    "Tags" : "Tag",
    "Custom" : "Ubahan",
    "Tag already exists" : "Tag sudah ada",
    "Add tag" : "Tambahkan tag",
    "Unsubscribe" : "Berhenti berlangganan",
    "Mark as unread" : "Tandai belum dibaca",
    "Mark as read" : "tandai sudah dibaca",
    "Untitled event" : "Acara tanpa judul",
    "(organizer)" : "(penyelenggara)",
    "Recipient" : "Penerima",
    "Operator" : "Operator",
    "contains" : "mengandung",
    "matches" : "cocok dengan",
    "Allow additional Mail accounts from User Settings" : "Perbolehkan akun Mail tambahan dari Setelan Pengguna",
    "Reset" : "Setel ulang",
    "Client ID" : "ID Klien",
    "Client secret" : "Rahasia klien",
    "User" : "Pengguna",
    "Host" : "Host",
    "Port" : "Port",
    "Valid until" : "Berlaku sampai",
    "Certificate" : "Sertifikat",
    "Account connected" : "Akun terhubung",
    "Connect your mail account" : "Hubungkan akun surel Anda",
    "All" : "Semua",
    "Drafts" : "Konsep",
    "Favorites" : "Disukai",
    "All inboxes" : "Semua kotak masuk",
    "Inbox" : "Kotak masuk",
    "Junk" : "Sampah",
    "Sent" : "Kirim",
    "Trash" : "Tempat sampah",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Discard changes" : "Buang perubahan",
    "Error loading message" : "Terjadi kesalahan saat memuat pesan",
    "Forwarding to %s" : "Teruskan ke %s",
    "Redirect" : "Mengalihkan",
    "Continue to %s" : "Lanjutkan ke %s",
    "Actions" : "Tindakan"
},
"nplurals=1; plural=0;");

==> nextcloud-app-mail-5.1.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/id.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Penting",
    "Work" : "Kantor",
    "Personal" : "Pribadi",
    "Later" : "Nanti",
    "Mail" : "Email",
    "Connecting" : "Menyambungkan",
    "Save" : "Simpan",
    "Connect" : "Sambungkan",
    "Password required" : "Kata sandi diperlukan",
    "Name" : "Nama",
    "Password" : "Kata kunci",
    "None" : "Tidak ada",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "Kata sandi SMTP",
    "Signature" : "Tanda",
    "Filters" : "Penyaring",
    "Go back" : "Kembali",
    "Email address" : "Alamat email",
    "Cancel" : "Membatalkan",
    "Accounts" : "Accounts",
    "Add mail account" : "Tambahkan akun email",
    "General" : "Umum",
    "List" : "Daftar",
    "Register" : "Daftar",
    "About" : "Tentang",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "Archive" : "Arsip",
    "Delete" : "Hapus",
    "Search" : "Cari",
    "Send" : "Kirim",
    "Refresh" : "Segarkan",
    "Subject" : "Subjek",
    "Upload attachment" : "Unggah lampiran",
    "Choose" : "Pilih",
    "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
    "Confirm" : "Konfirmasi",
    "Favorite" : "Favorit",
    "Read" : "Baca",
    "Edit tags" : "Sunting label",
    "Back" : "Kembali",
    "Create event" : "Buat acara",
    "All day" : "Sepanjang hari",
    "Description" : "Deskrisi",
    "Create" : "Buat",
    "Select" : "Pilih",
    "Comment" : "Komentar",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "Remove" : "Buang",
    "email" : "email",
    "Choose target folder" : "Pilih folder target",
    "Other" : "Lainnya",
    "Forward" : "Teruskan",
    "Translate" : "Terjemahkan",
    "Choose a folder to store the attachment in" : "Pilih folder untuk menyimpan lampiran didalamnya",
    "Import into calendar" : "Impor ke kalender",
    "Download attachment" : "Unduh lampiran",
    "Move" : "Pindah",
    "Loading …" : "Memuat …",
    "Remove account" : "Hapus akun",
    "Quota" : "Kuota",
    "Folder name" : "Nama folder",
    "Saving" : "Menyimpan",
    "Mark all as read" : "Tandai semua telah dibaca",
    "Rename" : "Ubah nama",
    "Clear cache" : "Bersihkan cache",
    "New message" : "Pesan baru",
    "Draft" : "Draf",
    "Reply" : "Balas",
    "Retry" : "Ulangi",
    "Message" : "Pesan",
    "Copy to clipboard" : "Salin ke papan klip",
    "Add" : "Masukkan",
    "Show less" : "Lihat sedikit",
    "Clear" : "Bersihkan",
    "Close" : "Tutup",
    "Date" : "Date",
    "Tags" : "Tag",
    "Custom" : "Ubahan",
    "Tag already exists" : "Tag sudah ada",
    "Add tag" : "Tambahkan tag",
    "Unsubscribe" : "Berhenti berlangganan",
    "Mark as unread" : "Tandai belum dibaca",
    "Mark as read" : "tandai sudah dibaca",
    "Untitled event" : "Acara tanpa judul",
    "(organizer)" : "(penyelenggara)",
    "Recipient" : "Penerima",
    "Operator" : "Operator",
    "contains" : "mengandung",
    "matches" : "cocok dengan",
    "Allow additional Mail accounts from User Settings" : "Perbolehkan akun Mail tambahan dari Setelan Pengguna",
    "Reset" : "Setel ulang",
    "Client ID" : "ID Klien",
    "Client secret" : "Rahasia klien",
    "User" : "Pengguna",
    "Host" : "Host",
    "Port" : "Port",
    "Valid until" : "Berlaku sampai",
    "Certificate" : "Sertifikat",
    "Account connected" : "Akun terhubung",
    "Connect your mail account" : "Hubungkan akun email Anda",
    "All" : "Semua",
    "Drafts" : "Konsep",
    "Favorites" : "Disukai",
    "All inboxes" : "Semua kotak masuk",
    "Inbox" : "Kotak masuk",
    "Junk" : "Sampah",
    "Sent" : "Kirim",
    "Trash" : "Tempat sampah",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Discard changes" : "Buang perubahan",
    "Error loading message" : "Terjadi kesalahan saat memuat pesan",
    "Forwarding to %s" : "Teruskan ke %s",
    "Redirect" : "Mengalihkan",
    "Continue to %s" : "Lanjutkan ke %s",
    "Actions" : "Tindakan"
},
"nplurals=1; plural=0;");
